@@ -1947,7 +1947,7 @@ def phot_mod_decals (gal, tab_gal, size_image_phy=50, snr_g = 2.0, areagal=2,
 
     plt.show()
 
-def mass_decals(gal, tab_gal, size_image_phy):
+def mass_decals(gal, tab_gal, size_image_phy, outputfile='properties.dat'):
 
     idg =np.where(tab_gal['gal']==gal[:-1])[0][0]
     D = tab_gal['vel'][idg]/H
@@ -1977,7 +1977,7 @@ def mass_decals(gal, tab_gal, size_image_phy):
     print('---------------------------------------------')
 
     home = 'https://www.legacysurvey.org/viewer/fits-cutout?'
-    path = 'fits_images/{}_{}_{}kpc.fits'.format(gal, 'g', size_image_phy)
+    path = 'fits_images/{}_{}_{}kpc.fits'.format(gal[:-1], 'g', size_image_phy)
     if not os.path.exists(path):
         print (f"\nDowloading {path} ...")
         part0 = 'ra={}&dec={}&layer=dr8-south&pixscale=0.27&bands=r&size={}'.format(
@@ -1989,7 +1989,7 @@ def mass_decals(gal, tab_gal, size_image_phy):
     else:
        print (f'\nThe image {path} already exist')
 
-    path = 'fits_images/{}_{}_{}kpc.fits'.format(gal, 'r', size_image_phy)
+    path = 'fits_images/{}_{}_{}kpc.fits'.format(gal[:-1], 'r', size_image_phy)
     if not os.path.exists(path):
         print (f"\nDowloading {path} ...")
         part0 = 'ra={}&dec={}&layer=dr8-south&pixscale=0.27&bands=r&size={}'.format(
@@ -2001,15 +2001,15 @@ def mass_decals(gal, tab_gal, size_image_phy):
     else:
         print (f'\nThe image {path} already exist')
 
-    imagn = fits.open('fits_images/{}_{}_{}kpc.fits'.format(gal, 'g',
+    imagn = fits.open('fits_images/{}_{}_{}kpc.fits'.format(gal[:-1], 'g',
                       size_image_phy))
     imag = imagn[0].data
 
-    imaxy = pfunc.callf('fits_images/{}_{}_{}kpc.fits'.format(gal, 'g',
+    imaxy = pfunc.callf('fits_images/{}_{}_{}kpc.fits'.format(gal[:-1], 'g',
                       size_image_phy))[0]
 
 
-    imarn = fits.open('fits_images/{}_{}_{}kpc.fits'.format(gal, 'r',
+    imarn = fits.open('fits_images/{}_{}_{}kpc.fits'.format(gal[:-1], 'r',
                       size_image_phy))
     imar = imarn[0].data
 
